==> owncloud-news_6.1.1%2Bdfsg.orig.tar.gz: news-6.1.1/l10n/sq.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Prurja përmban XML të pavleshme",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "S’u gjet prurje: ose sajti s’ofron prurje, ose bllokon hyrjet. Që të përjashtoni mundësinë e bllokimit, provoni ta shkarkoni prurjen që nga rreshti i urdhrave të shërbyesit tuaj, duke përdorur: curl http://the-feed.tld",
    "Detected feed format is not supported" : "Nuk mbulohet formati i zbuluar për prurjen",
    "SSL Certificate is invalid" : "Dëshmia SSL është e pavlefshme",
    "Website not found" : "S’u gjet sajt",
    "More redirects than allowed, aborting" : "Më tepër ridrejtime se sa lejohet, po ndërpritet",
    "Bigger than maximum allowed size" : "Më e madhe se sa madhësia maksimum e lejuar",
    "Request timed out" : "Kërkesës i mbaroi koha",
    "Request failed, network connection unavailable!" : "Kërkesa dështoi, s’funksionon lidhja në rrjet!",
    "Request unauthorized. Are you logged in?" : "Kërkesë e paautorizuar. Jeni i futur?",
    "Request forbidden. Are you an admin?" : "Kërkesë e ndaluar. Jeni një përgjegjës?",
    "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
    "Internal server error! Please check your " : "Gabimi brendshëm shërbyesi. Ju lutemi, kontrolloni ",
    "Request failed, ownCloud is in currently " : "Kërkesa dështoi, ownCloud-i gjendet hëpërhë në ",
    "Can not add feed: Exists already" : "Prurja s’shtohet dot: ekziston tashmë",
    "Articles without feed" : "Artikuj pa prurje",
    "Can not add folder: Exists already" : "S’shtohet dot dosje: ekziston tashmë",
    "Use ownCloud cron for updates" : "Për përditësime përdor cron-in e ownCloud-it",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Çaktivizojeni këtë, nëse xhironi një përditësues të personalizuar, fjala vjen përditësuesin Python të përfshirë te aplikacioni",
    "Purge interval" : "Interval pastrimi",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Sasi minimum sekondash pas të cilës prurjet dhe dosjet e fshira hiqen prej bazës së të dhënave; vlerat nën 60 sekonda nuk merren parasysh",
    "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Përcakton sasinë maksimum të artikujve për prurje që mund të lexohen dhe që s’do të fshihen nga akti i pastrimit; nëse rishfaqen artikuj të vjetër pasi janë lexuar, rriteni këtë vlerë; vlera negative, të tilla si -1, do ta çaktivizojnë plotësisht këtë veçori",
    "Maximum redirects" : "Maksimum ridrejtimesh",
    "How many redirects the feed fetcher should follow" : "Sa ridrejtime do të duhej të ndjekë sjellësi i prurjeve",
    "Maximum feed page size" : "Madhësi maksimum faqeje prurjesh",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Madhësi maksimum prurjeje në bajte. Nëse faqja RSS?Atom është më e madhe se kjo vlerë, përditësimi do të ndërpritet",
    "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Numër maksimum sekondash që duhet pritur për ngarkimin e një prurjeje RSS ose Atom; nëse zgjat më shumë, përditësimi do të ndërpritet",
    "Explore Service URL" : "URL Shërbimi Eksplorimesh",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Në u dhëntë, kjo URL shërbimi do të përdoret për të shfaqur prurje te ndarja Eksploroni Prurje. Që të përdoret shërbimi i brendshëm i eksplorimit, lëreni të zbrazët këtë fushë",
    "Saved" : "U ruajt",
    "Download" : "Shkarko",
    "Close" : "Mbylle",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "U zbulua mënyrë akti Ajax ose webcron! Prurjet tuaja nuk do të përditësohen saktësisht. Këshillohet që ose të përdorni cron-in e sistemit operativ, ose një përditësues të përshtatur.",
    "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
    "How to set up a custom updater (faster and no possible deadlock) " : "Si të rregullohet një përditësues i përshtatur (më i shpejtë dhe, sipas gjasash, pa ngecje) ",
    "Subscribe" : "Pajtohuni",
    "Refresh" : "Rifreskoje",
    "No articles available" : "Pa artikuj gati",
    "No unread articles available" : "Pa artikuj të palexuar gati",
    "Open website" : "Hap sajtin",
    "Star article" : "Vëri yll artikullit",
    "Unstar article" : "Hiqja yllin artikullit",
    "Keep article unread" : "Mbaje artikullin si të palexuar",
    "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
    "by" : "nga",
    "from" : "nga",
    "Play audio" : "Luaje audion",
    "Download video" : "Shkarko videon",
    "Download audio" : "Shkarko audion",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Description" : "Përshkrim",
    "right" : "djathtas",
    "Jump to next article" : "Hidhu te artikulli pasues",
    "left" : "majtas",
    "Jump to previous article" : "Hidhu te artikulli i mëparshëm",
    "Toggle star article" : "Vëri/hiqi yll artikullit",
    "Star article and jump to next one" : "Vëri yll artikullit dhe hidhu te pasuesi",
    "Toggle keep current article unread" : "Vëri/hiqi gjendjen mbaje artikullin të palexuar",
    "Open article in new tab" : "Hape artikullin në skedë të re",
    "Toggle expand article in compact view" : "Kaloje artikullin e zgjeruar nën pamjen kompakte",
    "Load next feed" : "Ngarko prurjen pasuese",
    "Load previous feed" : "Ngarko prurjen e mëparshme",
    "Load next folder" : "Ngarko dosjen pasuese",
    "Load previous folder" : "Ngarko dosjen e mëparshme",
    "Focus search field" : "Fokusohu te fusha e kërkimeve",
    "Mark current article's feed/folder read" : "Shënoje prurjen/dosjen e artikullit të tanishëm si të lexuar",
    "Web address" : "Adresë Web",
    "Feed exists already!" : "Prurja ekziston tashmë!",
    "Folder" : "Dosje",
    "No folder" : "Pa dosje",
    "New folder" : "Dosje e re",
    "Folder name" : "Emër dosjeje",
    "Go back" : "Kthehuni mbrapsht",
    "Folder exists already!" : "Ka një dosje të tillë!",
    "New Folder" : "Dosje e Re",
    "Create" : "Krijoje",
    "Explore" : "Eksploroni",
    "Deleted feed" : "Prurja u fshi",
    "Undo delete feed" : "Zhbëje fshirjen e prurjes",
    "Rename" : "Riemërtojeni",
    "Menu" : "Menu",
    "Unpin feed from the top" : "Shfiksoje prurjen prej kreut",
    "Pin feed to the top" : "Fiksoje prurjen në krye",
    "No feed ordering" : "Pa renditje prurjesh",
    "Reversed feed ordering" : "Renditje e përmbysur prurjesh",
    "Normal feed ordering" : "Renditje normale prurjesh",
    "Enable full text feed fetching" : "Aktivizo sjellje teksti të plotë prurjeje",
    "Disable full text feed fetching" : "Çaktivizo sjellje teksti të plotë prurjeje",
    "Keep updated articles as is" : "Artikujt e përditësuar mbaji siç janë",
    "Mark updated articles unread" : "Artikujt e përditësuar shënoji si të palexuar",
    "Rename feed" : "Riemërtoni prurjen",
    "Delete feed" : "Fshije prurjen",
    "Mark all articles read" : "Shënoji krejt artikujt si të lexuar",
    "Dismiss" : "Mos e merr parasysh",
    "Collapse" : "Tkurre",
    "Deleted folder" : "Dosja u fshi",
    "Undo delete folder" : "Zhbëje fshirjen e dosjes",
    "Rename folder" : "Riemërtoni dosjen",
    "Delete folder" : "Fshije dosjen",
    "Starred" : "Me yll",
    "Unread articles" : "Artikujt e palexuar",
    "All articles" : "Krejt artikujt",
    "Settings" : "Rregullimet",
    "Keyboard shortcuts" : "Shkurtore tastiere",
    "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
    "Compact view" : "Pamje kompakte",
    "Expand articles on key navigation" : "Zgjeroji artikujt kur lëvizet me tastierë",
    "Show all articles" : "Shfaqi krejt artikujt",
    "Reverse ordering (oldest on top)" : "Renditje e përmbusyr (më të vjetrat në krye)",
    "Subscriptions (OPML)" : "Pajtime (OPML)",
    "Import" : "Importo",
    "Export" : "Eksporto",
    "Error when importing: file does not contain valid OPML" : "Gabim gjatë importimit: kartela nuk përmban OPML të vlefshme",
    "Unread/Starred Articles" : "Artikuj të Palexuar/Me yll",
    "Error when importing: file does not contain valid JSON" : "Gabim gjatë importimit: kartela nuk përmban JSON të vlefshëm"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-news_7.0.1%2Bdfsg.orig.tar.gz: news-7.0.1/l10n/sq.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Prurja përmban XML të pavleshme",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "S’u gjet prurje: ose sajti s’ofron prurje, ose bllokon hyrjet. Që të përjashtoni mundësinë e bllokimit, provoni ta shkarkoni prurjen që nga rreshti i urdhrave të shërbyesit tuaj, duke përdorur: curl http://the-feed.tld",
    "Detected feed format is not supported" : "Nuk mbulohet formati i zbuluar për prurjen",
    "SSL Certificate is invalid" : "Dëshmia SSL është e pavlefshme",
    "Website not found" : "S’u gjet sajt",
    "More redirects than allowed, aborting" : "Më tepër ridrejtime se sa lejohet, po ndërpritet",
    "Bigger than maximum allowed size" : "Më e madhe se sa madhësia maksimum e lejuar",
    "Request timed out" : "Kërkesës i mbaroi koha",
    "Request failed, network connection unavailable!" : "Kërkesa dështoi, s’funksionon lidhja në rrjet!",
    "Request unauthorized. Are you logged in?" : "Kërkesë e paautorizuar. Jeni i futur?",
    "Request forbidden. Are you an admin?" : "Kërkesë e ndaluar. Jeni një përgjegjës?",
    "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
    "Internal server error! Please check your " : "Gabimi brendshëm shërbyesi. Ju lutemi, kontrolloni ",
    "Request failed, ownCloud is in currently " : "Kërkesa dështoi, ownCloud-i gjendet hëpërhë në ",
    "Can not add feed: Exists already" : "Prurja s’shtohet dot: ekziston tashmë",
    "Articles without feed" : "Artikuj pa prurje",
    "Can not add folder: Exists already" : "S’shtohet dot dosje: ekziston tashmë",
    "Use ownCloud cron for updates" : "Për përditësime përdor cron-in e ownCloud-it",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Çaktivizojeni këtë, nëse xhironi një përditësues të personalizuar, fjala vjen përditësuesin Python të përfshirë te aplikacioni",
    "Purge interval" : "Interval pastrimi",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Sasi minimum sekondash pas të cilës prurjet dhe dosjet e fshira hiqen prej bazës së të dhënave; vlerat nën 60 sekonda nuk merren parasysh",
    "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Përcakton sasinë maksimum të artikujve për prurje që mund të lexohen dhe që s’do të fshihen nga akti i pastrimit; nëse rishfaqen artikuj të vjetër pasi janë lexuar, rriteni këtë vlerë; vlera negative, të tilla si -1, do ta çaktivizojnë plotësisht këtë veçori",
    "Maximum redirects" : "Maksimum ridrejtimesh",
    "How many redirects the feed fetcher should follow" : "Sa ridrejtime do të duhej të ndjekë sjellësi i prurjeve",
    "Maximum feed page size" : "Madhësi maksimum faqeje prurjesh",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Madhësi maksimum prurjeje në bajte. Nëse faqja RSS?Atom është më e madhe se kjo vlerë, përditësimi do të ndërpritet",
    "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Numër maksimum sekondash që duhet pritur për ngarkimin e një prurjeje RSS ose Atom; nëse zgjat më shumë, përditësimi do të ndërpritet",
    "Explore Service URL" : "URL Shërbimi Eksplorimesh",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Në u dhëntë, kjo URL shërbimi do të përdoret për të shfaqur prurje te ndarja Eksploroni Prurje. Që të përdoret shërbimi i brendshëm i eksplorimit, lëreni të zbrazët këtë fushë",
    "Saved" : "U ruajt",
    "Download" : "Shkarko",
    "Close" : "Mbylle",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "U zbulua mënyrë akti Ajax ose webcron! Prurjet tuaja nuk do të përditësohen saktësisht. Këshillohet që ose të përdorni cron-in e sistemit operativ, ose një përditësues të përshtatur.",
    "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
    "How to set up a custom updater (faster and no possible deadlock) " : "Si të rregullohet një përditësues i përshtatur (më i shpejtë dhe, sipas gjasash, pa ngecje) ",
    "Subscribe" : "Pajtohuni",
    "Refresh" : "Rifreskoje",
    "No articles available" : "Pa artikuj gati",
    "No unread articles available" : "Pa artikuj të palexuar gati",
    "Open website" : "Hap sajtin",
    "Star article" : "Vëri yll artikullit",
    "Unstar article" : "Hiqja yllin artikullit",
    "Keep article unread" : "Mbaje artikullin si të palexuar",
    "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
    "by" : "nga",
    "from" : "nga",
    "Play audio" : "Luaje audion",
    "Download video" : "Shkarko videon",
    "Download audio" : "Shkarko audion",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Description" : "Përshkrim",
    "right" : "djathtas",
    "Jump to next article" : "Hidhu te artikulli pasues",
    "left" : "majtas",
    "Jump to previous article" : "Hidhu te artikulli i mëparshëm",
    "Toggle star article" : "Vëri/hiqi yll artikullit",
    "Star article and jump to next one" : "Vëri yll artikullit dhe hidhu te pasuesi",
    "Toggle keep current article unread" : "Vëri/hiqi gjendjen mbaje artikullin të palexuar",
    "Open article in new tab" : "Hape artikullin në skedë të re",
    "Toggle expand article in compact view" : "Kaloje artikullin e zgjeruar nën pamjen kompakte",
    "Load next feed" : "Ngarko prurjen pasuese",
    "Load previous feed" : "Ngarko prurjen e mëparshme",
    "Load next folder" : "Ngarko dosjen pasuese",
    "Load previous folder" : "Ngarko dosjen e mëparshme",
    "Scroll to active navigation entry" : "Rrëshqiteni që të aktivizohet lëvizja për elementin",
    "Focus search field" : "Kaloje fokusin te fusha e kërkimeve",
    "Mark current article's feed/folder read" : "Shënoje prurjen/dosjen e artikullit të tanishëm si të lexuar",
    "Web address" : "Adresë Web",
    "Feed exists already!" : "Prurja ekziston tashmë!",
    "Folder" : "Dosje",
    "No folder" : "Pa dosje",
    "New folder" : "Dosje e re",
    "Folder name" : "Emër dosjeje",
    "Go back" : "Kthehuni mbrapsht",
    "Folder exists already!" : "Ka një dosje të tillë!",
    "New Folder" : "Dosje e Re",
    "Create" : "Krijoje",
    "Explore" : "Eksploroni",
    "Update failed more than 50 times" : "Përditësimi dështoi më shumë se 50 herë",
    "Deleted feed" : "Prurja u fshi",
    "Undo delete feed" : "Zhbëje fshirjen e prurjes",
    "Rename" : "Riemërtojeni",
    "Menu" : "Menu",
    "Unpin feed from the top" : "Shfiksoje prurjen prej kreut",
    "Pin feed to the top" : "Fiksoje prurjen në krye",
    "No feed ordering" : "Pa renditje prurjesh",
    "Reversed feed ordering" : "Renditje e përmbysur prurjesh",
    "Normal feed ordering" : "Renditje normale prurjesh",
    "Enable full text feed fetching" : "Aktivizo sjellje teksti të plotë prurjeje",
    "Disable full text feed fetching" : "Çaktivizo sjellje teksti të plotë prurjeje",
    "Keep updated articles as is" : "Artikujt e përditësuar mbaji siç janë",
    "Mark updated articles unread" : "Artikujt e përditësuar shënoji si të palexuar",
    "Rename feed" : "Riemërtoni prurjen",
    "Delete feed" : "Fshije prurjen",
    "Mark all articles read" : "Shënoji krejt artikujt si të lexuar",
    "Dismiss" : "Mos e merr parasysh",
    "Collapse" : "Tkurre",
    "Deleted folder" : "Dosja u fshi",
    "Undo delete folder" : "Zhbëje fshirjen e dosjes",
    "Rename folder" : "Riemërtoni dosjen",
    "Delete folder" : "Fshije dosjen",
    "Starred" : "Me yll",
    "Unread articles" : "Artikujt e palexuar",
    "All articles" : "Krejt artikujt",
    "Settings" : "Rregullimet",
    "Keyboard shortcuts" : "Shkurtore tastiere",
    "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
    "Compact view" : "Pamje kompakte",
    "Expand articles on key navigation" : "Zgjeroji artikujt kur lëvizet me tastierë",
    "Show all articles" : "Shfaqi krejt artikujt",
    "Reverse ordering (oldest on top)" : "Renditje e përmbusyr (më të vjetrat në krye)",
    "Subscriptions (OPML)" : "Pajtime (OPML)",
    "Import" : "Importo",
    "Export" : "Eksporto",
    "Error when importing: file does not contain valid OPML" : "Gabim gjatë importimit: kartela nuk përmban OPML të vlefshme",
    "Unread/Starred Articles" : "Artikuj të Palexuar/Me yll",
    "Error when importing: file does not contain valid JSON" : "Gabim gjatë importimit: kartela nuk përmban JSON të vlefshëm"
},
"nplurals=2; plural=(n != 1);");
